## Plan Update

This is an opportunity to update the state of the plan based on our results.

### Updating or Completing the Plan

Based on the results thus far, you need to update the state of the plan. You can either:

- Mark the plan as `complete` if the existing hypothesis results can answer the initial question(s) we set out to answer.
- Mark the plan as `failed` if we are unable to answer the initial question(s) and the current team composition or team member failures prevent us from continuing our work.
- Mark the plan as `in_progress` if we're not ready to answer the initial question(s) yet. 
    - If there are no remaining `unverified` hypotheses, then you will need to include additional hypotheses to the plan.
    - If the remaining hypotheses are no longer relevant due to new information, then you will need to include additional hypotheses to the plan - we will action the newest hypotheses first.

### Adding New Hypotheses

If there are no remaining `unverified` hypotheses, and you believe, given the current state of the plan, that we can still make progress, then you need to propose some new hypotheses to add to the plan.

### Tips

- We can't interact with the physical world, and you're basically limited to whatever functionality your team members have. Keep this in mind when you are adding new hypotheses.
- Be sure to consider your team member's descriptions. Unless explicitly mentioned, they cannot perform arbitrary tasks and are limited to the functionality provided in their descriptions.
- If any of your new hypotheses required functionality not obviously available to your team members, you should fail the plan.
